==> 12.5.0.tar.gz: webid-document-scanner-spm/Package.swift <==
// swift-tools-version:5.3
// The swift-tools-version declares the minimum version of Swift required to build this package.

import PackageDescription

let package = Package(
    name: "WebIdDocumentScanner",
    platforms: [
        .iOS(.v13)
    ],
    products: [
        // Products define the executables and libraries a package produces, and make them visible to other packages.
        .library(name: "WebIdDocumentScanner", targets: ["WebIdDocumentScannerWrapper"]),
    ],
    dependencies: [
        // Dependencies declare other packages that this package depends on.
        .package(
            name: "WebIdPluginCore",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackages/webid-plugin-core-spm.git",
            .exact("12.3.1")
        )
    ],
    targets: [
        .binaryTarget(
            name: "WebIdDocumentScanner",
            url: "https://api.webid-solutions.de/releases/ios/xcframework/internal/de/webid-solutions/WebIdDocumentScanner/12.5.0/WebIdDocumentScanner.framework-v12.5.0.zip",
            checksum: "5475289206e107038f80942938ed817248f532c07ad97b111c6633e86cc5b078"
        ),
        .target(
            name: "WebIdDocumentScannerWrapper",
            dependencies: [
                .target(name: "WebIdDocumentScanner"),
                // [target dependecies here]
                
                .product(name: "WebIdPluginCore", package: "WebIdPluginCore"),
            ]
        )
    ],
    swiftLanguageVersions: [SwiftVersion.v5]
)

==> 20.0.0.tar.gz: webid-document-scanner-spm/Package.swift <==
// swift-tools-version:5.3
// The swift-tools-version declares the minimum version of Swift required to build this package.

import PackageDescription

let package = Package(
    name: "WebIdDocumentScanner",
    platforms: [
        .iOS(.v13)
    ],
    products: [
        // Products define the executables and libraries a package produces, and make them visible to other packages.
        .library(name: "WebIdDocumentScanner", targets: ["WebIdDocumentScannerWrapper"]),
    ],
    dependencies: [
        // Dependencies declare other packages that this package depends on.
        .package(
            name: "WebIdPluginCore",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackageRedesignV4/webid-plugin-core-spm.git",
            .exact("20.0.0")
        )
    ],
    targets: [
        .binaryTarget(
            name: "WebIdDocumentScanner",
            url: "https://api.webid-solutions.de/releases/ios/xcframework/redesign-v4/de/webid-solutions/WebIdDocumentScanner/20.0.0/WebIdDocumentScanner.framework-v20.0.0.zip",
            checksum: "f0ea944499379c905ac369b3fcd5053eedbdb710a2278a46c8ebd0612979a672"
        ),
        .target(
            name: "WebIdDocumentScannerWrapper",
            dependencies: [
                .target(name: "WebIdDocumentScanner"),
                // [target dependecies here]
                
                .product(name: "WebIdPluginCore", package: "WebIdPluginCore"),
            ]
        )
    ],
    swiftLanguageVersions: [SwiftVersion.v5]
)
